@@ -40,7 +40,7 @@ class InternetDynamicFields(ProvisionDynamicFields):
 
     def _previous_provider(self):
         provider = None
-        if not self.service_data.change_address:
+        if self.service_data.change_address == "no":
             provider = self.service_data.previous_provider
         return DynamicField(name="proveidorPrevi", value=provider)
 
