@@ -26,7 +26,7 @@ class ProvisionDynamicFields():
             self._product(),
         ]
         dynamic_fields += self._build_specific_dynamic_fields()
-        return [field for field in dynamic_fields if field.value is not None]
+        return [field for field in dynamic_fields if field.value]
 
     def _process_id(self):
         return DynamicField(name="ProcessManagementProcessID", value=self.otrs_process_id)
