@@ -26,6 +26,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'product',
         ])
         customer_data = Mock(spec=[
+            'id',
             'first_name',
             'name',
             'vat_number',
@@ -83,7 +84,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'product',
             'previous_internal_provider',
         ])
-        customer_data = Mock(spec=['first_name', 'name', 'vat_number', 'email', 'phone'])
+        customer_data = Mock(spec=['id', 'first_name', 'name', 'vat_number', 'email', 'phone'])
 
         service_data.type = 'adsl'
 
@@ -132,7 +133,7 @@ class TicketFactoryIntegrationTestCase(unittest.TestCase):
             'product',
             'previous_internal_provider',
         ])
-        customer_data = Mock(spec=['first_name', 'name', 'vat_number', 'email', 'phone'])
+        customer_data = Mock(spec=['id', 'first_name', 'name', 'vat_number', 'email', 'phone'])
 
         service_data.type = 'fiber'
 
