@@ -181,7 +181,7 @@ class ADSLDynamicFieldsTestCase(unittest.TestCase):
 
     def test_previous_provider_field(self):
         self.service_data.previous_provider = "Nubip"
-        self.service_data.change_address = False
+        self.service_data.change_address = "no"
 
         dynamic_fields = ADSLDynamicFields(
             self.service_data,
