@@ -181,7 +181,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
 
     def test_previous_provider_field(self):
         self.service_data.previous_provider = "SomConnexio"
-        self.service_data.change_address = False
+        self.service_data.change_address = "no"
 
         dynamic_fields = FiberDynamicFields(
             self.service_data,
@@ -414,7 +414,7 @@ class FiberDynamicFieldsTestCase(unittest.TestCase):
         dynamic_fields_dct = dynamic_fields_to_dct(dynamic_fields)
         self.assertEqual(dynamic_fields_dct["canviUbicacioMateixTitular"], "yes")
 
-    def test_change_address_field_doent_set(self):
+    def test_change_address_field_doesnt_set(self):
         self.service_data.change_address = "no"
 
         dynamic_fields = FiberDynamicFields(
