@@ -4,15 +4,13 @@ from mock import Mock, patch
 
 from otrs_somconnexio.otrs_models.fiber_ticket import FiberTicket
 from otrs_somconnexio.otrs_models.configurations.fiber_ticket import FiberTicketConfiguration
-from otrs_somconnexio.exceptions import CustomerMailMissing
 
 
 class FiberTicketTestCase(unittest.TestCase):
 
     @patch('otrs_somconnexio.otrs_models.provision_ticket.Ticket')
     def test_build_ticket(self, MockTicket):
-        customer_data = Mock(spec=['email'])
-        customer_data.email = 'contact@mail.com'
+        customer_data = Mock(spec=['id'])
         service_data = Mock(spec=['order_id'])
 
         expected_ticket_arguments = {
@@ -21,8 +19,8 @@ class FiberTicketTestCase(unittest.TestCase):
             "Queue": FiberTicketConfiguration.queue,
             "State": FiberTicketConfiguration.state,
             "Priority": FiberTicketConfiguration.priority,
-            "CustomerUser": 'contact@mail.com',
-            "CustomerID": 'contact@mail.com'
+            "CustomerUser": customer_data.id,
+            "CustomerID": customer_data.id
         }
 
         FiberTicket(service_data, customer_data)._build_ticket()
@@ -105,26 +103,3 @@ class FiberTicketTestCase(unittest.TestCase):
 
         self.assertEqual(ticket.id, 123)
         self.assertEqual(ticket.number, '#123')
-
-    @patch('otrs_somconnexio.otrs_models.provision_ticket.OTRSClient')
-    def test_create_raise_customer_email_missing_exeception(self, MockOTRSClient):
-        service_data = Mock(spec=['order_id'])
-        service_data.order_id = 4321
-        customer_data = Mock(spec=[
-            'id',
-            'email',
-            'phone',
-            'first_name',
-            'name',
-            'vat_number',
-        ])
-        customer_data.id = 1234
-        customer_data.email = None
-
-        ticket = FiberTicket(service_data, customer_data)
-
-        self.assertRaisesRegexp(
-            CustomerMailMissing,
-            "Customer without mail in order ID {}".format(service_data.order_id),
-            ticket.create
-        )
