@@ -4,7 +4,6 @@ from mock import Mock, patch
 
 from otrs_somconnexio.otrs_models.mobile_ticket import MobileTicket
 from otrs_somconnexio.otrs_models.configurations.mobile_ticket import MobileTicketConfiguration
-from otrs_somconnexio.exceptions import CustomerMailMissing
 
 
 class MobileTicketTestCase(unittest.TestCase):
@@ -28,8 +27,8 @@ class MobileTicketTestCase(unittest.TestCase):
             "Queue": MobileTicketConfiguration.queue,
             "State": MobileTicketConfiguration.state,
             "Priority": MobileTicketConfiguration.priority,
-            "CustomerUser": 'contact@mail.com',
-            "CustomerID": 'contact@mail.com'
+            "CustomerUser": customer_data.id,
+            "CustomerID": customer_data.id,
         }
 
         MobileTicket(mobile_data, customer_data)._build_ticket()
@@ -113,42 +112,3 @@ class MobileTicketTestCase(unittest.TestCase):
 
         self.assertEqual(ticket.id, 123)
         self.assertEqual(ticket.number, '#123')
-
-    @patch('otrs_somconnexio.otrs_models.provision_ticket.OTRSClient')
-    def test_create_raise_customer_email_missing_exeception(self, MockOTRSClient):
-        mobile_data = Mock(spec=[
-            'order_id',
-            'iban',
-            'phone_number',
-            'sc_icc',
-            'icc',
-            'portability',
-            'previous_provider',
-            'previous_owner_vat',
-            'previous_owner_name',
-            'previous_owner_surname',
-            'product',
-        ])
-        mobile_data.order_id = 4321
-
-        customer_data = Mock(spec=[
-            'id',
-            'email',
-            'phone',
-            'first_name',
-            'name',
-            'vat_number',
-            'street',
-            'city',
-            'zip',
-            'subdivision',
-        ])
-        customer_data.id = 1234
-        customer_data.email = None
-
-        ticket = MobileTicket(mobile_data, customer_data)
-        self.assertRaisesRegexp(
-            CustomerMailMissing,
-            "Customer without mail in order ID {}".format(mobile_data.order_id),
-            ticket.create
-        )
